Class: Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1EgressSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1beta1/classes.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb

Overview

The source that EgressPolicy authorizes access from inside the ServicePerimeter to somewhere outside the ServicePerimeter boundaries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1EgressSource

Returns a new instance of GoogleIdentityAccesscontextmanagerV1EgressSource.



1604
1605
1606
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_levelString

An AccessLevel resource name that allows protected resources inside the ServicePerimeters to access outside the ServicePerimeter boundaries. AccessLevels listed must be in the same policy as this ServicePerimeter. Referencing a nonexistent AccessLevel will cause an error. If an AccessLevel name is not specified, only resources within the perimeter can be accessed through Google Cloud calls with request origins within the perimeter. Example: accessPolicies/MY_POLICY/accessLevels/MY_LEVEL. If a single * is specified for access_level, then all EgressSources will be allowed. Corresponds to the JSON property accessLevel

Returns:

  • (String)


1589
1590
1591
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1589

def access_level
  @access_level
end

#psc_endpointGoogle::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint

Specifies the PSC an API call refers to. Corresponds to the JSON property pscEndpoint



1594
1595
1596
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1594

def psc_endpoint
  @psc_endpoint
end

#resourceString

A Google Cloud resource from the service perimeter that you want to allow to access data outside the perimeter. This field supports only projects. The project format is projects/project_number`. You can't use*in this field to allow all Google Cloud resources. Corresponds to the JSON propertyresource`

Returns:

  • (String)


1602
1603
1604
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1602

def resource
  @resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1609
1610
1611
1612
1613
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1609

def update!(**args)
  @access_level = args[:access_level] if args.key?(:access_level)
  @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint)
  @resource = args[:resource] if args.key?(:resource)
end