Class: Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1IngressTo
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1IngressTo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1beta1/classes.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb
Overview
Defines the conditions under which an IngressPolicy matches a request.
Conditions are based on information about the ApiOperation intended to be
performed on the target resource of the request. The request must satisfy what
is defined in operations AND resources in order to match.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1ApiOperation>
A list of ApiOperations allowed to be performed by the sources specified in corresponding IngressFrom in this ServicePerimeter.
-
#resources ⇒ Array<String>
A list of resources, currently only projects in the form
projects/, protected by this ServicePerimeter that are allowed to be accessed by sources defined in the corresponding IngressFrom. -
#roles ⇒ Array<String>
IAM roles that represent the set of operations that the sources specified in the corresponding IngressFrom are allowed to perform in this ServicePerimeter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressTo
constructor
A new instance of GoogleIdentityAccesscontextmanagerV1IngressTo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressTo
Returns a new instance of GoogleIdentityAccesscontextmanagerV1IngressTo.
1831 1832 1833 |
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1ApiOperation>
A list of ApiOperations allowed to be performed by the sources specified in
corresponding IngressFrom in this ServicePerimeter.
Corresponds to the JSON property operations
1815 1816 1817 |
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1815 def operations @operations end |
#resources ⇒ Array<String>
A list of resources, currently only projects in the form projects/,
protected by this ServicePerimeter that are allowed to be accessed by sources
defined in the corresponding IngressFrom. If a single * is specified, then
access to all resources inside the perimeter are allowed.
Corresponds to the JSON property resources
1823 1824 1825 |
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1823 def resources @resources end |
#roles ⇒ Array<String>
IAM roles that represent the set of operations that the sources specified in
the corresponding IngressFrom are allowed to perform in this ServicePerimeter.
Corresponds to the JSON property roles
1829 1830 1831 |
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1829 def roles @roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1836 1837 1838 1839 1840 |
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1836 def update!(**args) @operations = args[:operations] if args.key?(:operations) @resources = args[:resources] if args.key?(:resources) @roles = args[:roles] if args.key?(:roles) end |