Class: Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1MethodSelector

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1beta1/classes.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb

Overview

An allowed method or permission of a service specified in ApiOperation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1MethodSelector

Returns a new instance of GoogleIdentityAccesscontextmanagerV1MethodSelector.



1825
1826
1827
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#method_propString

A valid method name for the corresponding service_name in ApiOperation. If * is used as the value for the method, then ALL methods and permissions are allowed. Corresponds to the JSON property method

Returns:

  • (String)


1817
1818
1819
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1817

def method_prop
  @method_prop
end

#permissionString

A valid Cloud IAM permission for the corresponding service_name in ApiOperation. Corresponds to the JSON property permission

Returns:

  • (String)


1823
1824
1825
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1823

def permission
  @permission
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1830
1831
1832
1833
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1830

def update!(**args)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @permission = args[:permission] if args.key?(:permission)
end