Class: Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1OsConstraint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1beta1/classes.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb

Overview

A restriction on the OS type and version of devices making requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1OsConstraint

Returns a new instance of GoogleIdentityAccesscontextmanagerV1OsConstraint.



1915
1916
1917
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1915

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#minimum_versionString

The minimum allowed OS version. If not set, any version of this OS satisfies the constraint. Format: "major.minor.patch". Examples: "10.5.301", "9.2.1" . Corresponds to the JSON property minimumVersion

Returns:

  • (String)


1899
1900
1901
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1899

def minimum_version
  @minimum_version
end

#os_typeString

Required. The allowed OS type. Corresponds to the JSON property osType

Returns:

  • (String)


1904
1905
1906
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1904

def os_type
  @os_type
end

#require_verified_chrome_osBoolean Also known as: require_verified_chrome_os?

Only allows requests from devices with a verified Chrome OS. Verifications includes requirements that the device is enterprise-managed, conformant to domain policies, and the caller has permission to call the API targeted by the request. Corresponds to the JSON property requireVerifiedChromeOs

Returns:

  • (Boolean)


1912
1913
1914
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1912

def require_verified_chrome_os
  @require_verified_chrome_os
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1920
1921
1922
1923
1924
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1920

def update!(**args)
  @minimum_version = args[:minimum_version] if args.key?(:minimum_version)
  @os_type = args[:os_type] if args.key?(:os_type)
  @require_verified_chrome_os = args[:require_verified_chrome_os] if args.key?(:require_verified_chrome_os)
end