Class: Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1ServicePattern
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1ServicePattern
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1beta1/classes.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb
Overview
Service patterns used to allow access.
Instance Attribute Summary collapse
-
#modifiers ⇒ Array<Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1Modifier>
Modifiers to apply to the requests that match the URL pattern.
-
#pattern ⇒ String
URL pattern to allow.
-
#service ⇒ String
Supported service to allow.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1ServicePattern
constructor
A new instance of GoogleIdentityAccesscontextmanagerV1ServicePattern.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1ServicePattern
Returns a new instance of GoogleIdentityAccesscontextmanagerV1ServicePattern.
1969 1970 1971 |
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1969 def initialize(**args) update!(**args) end |
Instance Attribute Details
#modifiers ⇒ Array<Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1Modifier>
Modifiers to apply to the requests that match the URL pattern.
Corresponds to the JSON property modifiers
1955 1956 1957 |
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1955 def modifiers @modifiers end |
#pattern ⇒ String
URL pattern to allow. Only patterns of ".googleapis.com/", "www.googleapis.
com//" and ".appspot.com/ forms are supported, where should be
alphanumerical name.
Corresponds to the JSON property pattern
1962 1963 1964 |
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1962 def pattern @pattern end |
#service ⇒ String
Supported service to allow.
Corresponds to the JSON property service
1967 1968 1969 |
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1967 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1974 1975 1976 1977 1978 |
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1974 def update!(**args) @modifiers = args[:modifiers] if args.key?(:modifiers) @pattern = args[:pattern] if args.key?(:pattern) @service = args[:service] if args.key?(:service) end |