Class: Google::Apis::CloudassetV1beta1::Resource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1beta1/classes.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb

Overview

A representation of a Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Resource

Returns a new instance of Resource.



2335
2336
2337
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataHash<String,Object>

The content of the resource, in which some sensitive fields are removed and may not be present. Corresponds to the JSON property data

Returns:

  • (Hash<String,Object>)


2294
2295
2296
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2294

def data
  @data
end

#discovery_document_uriString

The URL of the discovery document containing the resource's JSON schema. Example: https://www.googleapis.com/discovery/v1/apis/compute/v1/rest This value is unspecified for resources that do not have an API based on a discovery document, such as Cloud Bigtable. Corresponds to the JSON property discoveryDocumentUri

Returns:

  • (String)


2302
2303
2304
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2302

def discovery_document_uri
  @discovery_document_uri
end

#discovery_nameString

The JSON schema name listed in the discovery document. Example: Project This value is unspecified for resources that do not have an API based on a discovery document, such as Cloud Bigtable. Corresponds to the JSON property discoveryName

Returns:

  • (String)


2309
2310
2311
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2309

def discovery_name
  @discovery_name
end

#parentString

The full name of the immediate parent of this resource. See Resource Names for more information. For Google Cloud assets, this value is the parent resource defined in the IAM policy hierarchy. Example: //cloudresourcemanager.googleapis.com/ projects/my_project_123 For third-party assets, this field may be set differently. Corresponds to the JSON property parent

Returns:

  • (String)


2320
2321
2322
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2320

def parent
  @parent
end

#resource_urlString

The REST URL for accessing the resource. An HTTP GET request using this URL returns the resource itself. Example: https://cloudresourcemanager.googleapis. com/v1/projects/my-project-123 This value is unspecified for resources without a REST API. Corresponds to the JSON property resourceUrl

Returns:

  • (String)


2328
2329
2330
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2328

def resource_url
  @resource_url
end

#versionString

The API version. Example: v1 Corresponds to the JSON property version

Returns:

  • (String)


2333
2334
2335
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2333

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2340
2341
2342
2343
2344
2345
2346
2347
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2340

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @discovery_document_uri = args[:discovery_document_uri] if args.key?(:discovery_document_uri)
  @discovery_name = args[:discovery_name] if args.key?(:discovery_name)
  @parent = args[:parent] if args.key?(:parent)
  @resource_url = args[:resource_url] if args.key?(:resource_url)
  @version = args[:version] if args.key?(:version)
end