Class: Google::Apis::CloudassetV1beta1::TemporalAsset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1beta1/classes.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb

Overview

An asset in Google Cloud and its temporal metadata, including the time window when it was observed and its status during that window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TemporalAsset

Returns a new instance of TemporalAsset.



2538
2539
2540
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2538

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetGoogle::Apis::CloudassetV1beta1::Asset

An asset in Google Cloud. An asset can be any resource in the Google Cloud resource hierarchy, a resource outside the Google Cloud resource hierarchy (such as Google Kubernetes Engine clusters and objects), or a policy (e.g. IAM policy). See Supported asset types for more information. Corresponds to the JSON property asset



2525
2526
2527
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2525

def asset
  @asset
end

#deletedBoolean Also known as: deleted?

Whether the asset has been deleted or not. Corresponds to the JSON property deleted

Returns:

  • (Boolean)


2530
2531
2532
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2530

def deleted
  @deleted
end

#windowGoogle::Apis::CloudassetV1beta1::TimeWindow

A time window specified by its start_time and end_time. Corresponds to the JSON property window



2536
2537
2538
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2536

def window
  @window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2543
2544
2545
2546
2547
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 2543

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @deleted = args[:deleted] if args.key?(:deleted)
  @window = args[:window] if args.key?(:window)
end