Class: Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1IngressFrom

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1beta1/classes.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb,
lib/google/apis/cloudasset_v1beta1/representations.rb

Overview

Defines the conditions under which an IngressPolicy matches a request. Conditions are based on information about the source of the request. The request must satisfy what is defined in sources AND identity related fields in order to match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressFrom

Returns a new instance of GoogleIdentityAccesscontextmanagerV1IngressFrom.



1670
1671
1672
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identitiesArray<String>

A list of identities that are allowed access through [IngressPolicy]. Identities can be an individual user, service account, Google group, or third- party identity. For third-party identity, only single identities are supported and other identity types are not supported. The v1 identities that have the prefix user, group, serviceAccount, and principal in https://cloud. google.com/iam/docs/principal-identifiers#v1 are supported. Corresponds to the JSON property identities

Returns:

  • (Array<String>)


1656
1657
1658
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1656

def identities
  @identities
end

#identity_typeString

Specifies the type of identities that are allowed access from outside the perimeter. If left unspecified, then members of identities field will be allowed access. Corresponds to the JSON property identityType

Returns:

  • (String)


1663
1664
1665
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1663

def identity_type
  @identity_type
end

#sourcesArray<Google::Apis::CloudassetV1beta1::GoogleIdentityAccesscontextmanagerV1IngressSource>

Sources that this IngressPolicy authorizes access from. Corresponds to the JSON property sources



1668
1669
1670
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1668

def sources
  @sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1675
1676
1677
1678
1679
# File 'lib/google/apis/cloudasset_v1beta1/classes.rb', line 1675

def update!(**args)
  @identities = args[:identities] if args.key?(:identities)
  @identity_type = args[:identity_type] if args.key?(:identity_type)
  @sources = args[:sources] if args.key?(:sources)
end